@@ -15,6 +15,7 @@ mod use_event;
 mod use_favicon;
 mod use_geolocation;
 mod use_hash;
+mod use_infinite_scroll;
 mod use_interval;
 mod use_is_first_mount;
 mod use_is_mounted;
@@ -69,6 +70,7 @@ pub use use_event::*;
 pub use use_favicon::*;
 pub use use_geolocation::*;
 pub use use_hash::*;
+pub use use_infinite_scroll::*;
 pub use use_interval::*;
 pub use use_is_first_mount::*;
 pub use use_is_mounted::*;
